@@ -64,6 +64,7 @@
 #include "gnc-main-window.h"
 #include "gnc-plugin.h"
 #include "gnc-plugin-page-sx-list.h"
+#include "gnc-prefs.h"
 #include "gnc-session.h"
 #include "gnc-sx-instance-dense-cal-adapter.h"
 #include "gnc-sx-instance-model.h"
@@ -80,6 +81,8 @@ G_GNUC_UNUSED static QofLogModule log_module = GNC_MOD_GUI_SX;
 
 #define PLUGIN_PAGE_SX_LIST_CM_CLASS "plugin-page-sx-list"
 #define STATE_SECTION "SX Transaction List"
+#define GNC_PREF_DIVIDER_POS "divider-position"
+#define GNC_PREF_NUM_OF_MONTHS "number-of-months"
 
 typedef struct GncPluginPageSxListPrivate
 {
@@ -120,6 +123,7 @@ static void gnc_plugin_page_sx_list_cmd_new (GSimpleAction *simple, GVariant *pa
 static void gnc_plugin_page_sx_list_cmd_edit (GSimpleAction *simple, GVariant *paramter, gpointer user_data);
 static void gnc_plugin_page_sx_list_cmd_delete (GSimpleAction *simple, GVariant *paramter, gpointer user_data);
 static void gnc_plugin_page_sx_list_cmd_refresh (GSimpleAction *simple, GVariant *paramter, gpointer user_data);
+static void gnc_plugin_page_sx_list_cmd_save_layout (GSimpleAction *simple, GVariant *paramter, gpointer user_data);
 static void gnc_plugin_page_sx_list_cmd_edit_tax_options (GSimpleAction *simple, GVariant *paramter, gpointer user_data);
 
 /* Command callbacks */
@@ -130,6 +134,7 @@ static GActionEntry gnc_plugin_page_sx_list_actions [] =
     { "SxListEditAction", gnc_plugin_page_sx_list_cmd_edit, NULL, NULL, NULL },
     { "SxListDeleteAction", gnc_plugin_page_sx_list_cmd_delete, NULL, NULL, NULL },
     { "ViewRefreshAction", gnc_plugin_page_sx_list_cmd_refresh, NULL, NULL, NULL },
+    { "ViewSaveLayoutAction", gnc_plugin_page_sx_list_cmd_save_layout, NULL, NULL, NULL },
     { "EditTaxOptionsAction", gnc_plugin_page_sx_list_cmd_edit_tax_options, NULL, NULL, NULL },
 };
 /** The number of actions provided by this plugin. */
@@ -500,12 +505,10 @@ gnc_plugin_page_sx_list_create_widget (GncPluginPage *plugin_page)
     gtk_box_pack_start (GTK_BOX(vbox), swin, TRUE, TRUE, 5);
     gtk_widget_show (swin);
 
-    {
-        // gint half_way;
-        // half_way = plugin_page->notebook_page->allocation.height * 0.5;
-        // fixme; get a real value:
-        gtk_paned_set_position (GTK_PANED(priv->widget), 160);
-    }
+    /* Set the paned position from the preferences, default 160 */
+    gtk_paned_set_position (GTK_PANED(priv->widget),
+                            gnc_prefs_get_float (GNC_PREFS_GROUP_SXED,
+                                                 GNC_PREF_DIVIDER_POS));
 
     {
         GDate end;
@@ -578,8 +581,10 @@ gnc_plugin_page_sx_list_create_widget (GncPluginPage *plugin_page)
         priv->gdcal = GNC_DENSE_CAL(gnc_dense_cal_new_with_model (window, GNC_DENSE_CAL_MODEL(priv->dense_cal_model)));
         g_object_ref_sink (priv->gdcal);
 
-        gnc_dense_cal_set_months_per_col (priv->gdcal, 4);
-        gnc_dense_cal_set_num_months (priv->gdcal, 12);
+        /* Set number of months from preference, default 12 */
+        gchar *num_months = gnc_prefs_get_string (GNC_PREFS_GROUP_SXED, GNC_PREF_NUM_OF_MONTHS);
+        gnc_dense_cal_set_num_months (priv->gdcal, atoi (num_months));
+        g_free (num_months);
 
         gtk_container_add (GTK_CONTAINER(swin), GTK_WIDGET(priv->gdcal));
     }
@@ -751,6 +756,32 @@ gnc_plugin_page_sx_list_cmd_refresh (GSimpleAction *simple,
     gtk_widget_queue_draw (priv->widget);
 }
 
+static void
+gnc_plugin_page_sx_list_cmd_save_layout (GSimpleAction *simple,
+                                         GVariant      *parameter,
+                                         gpointer       user_data)
+{
+    auto plugin_page = GNC_PLUGIN_PAGE_SX_LIST(user_data);
+    GncPluginPageSxListPrivate *priv;
+    gchar *num_of_months;
+    gint paned_position;
+
+    g_return_if_fail (GNC_IS_PLUGIN_PAGE_SX_LIST(plugin_page));
+
+    priv = GNC_PLUGIN_PAGE_SX_LIST_GET_PRIVATE(plugin_page);
+
+    num_of_months = g_strdup_printf ("%d", gnc_dense_cal_get_num_months (priv->gdcal));
+    paned_position = gtk_paned_get_position (GTK_PANED(priv->widget));
+
+    gnc_prefs_set_float (GNC_PREFS_GROUP_SXED, GNC_PREF_DIVIDER_POS,
+                         paned_position);
+
+    gnc_prefs_set_string (GNC_PREFS_GROUP_SXED, GNC_PREF_NUM_OF_MONTHS,
+                          num_of_months);
+
+    g_free (num_of_months);
+}
+
 static void
 _edit_sx(gpointer data, gpointer user_data)
 {
