@@ -44,6 +44,7 @@
 
 #include "import-main-matcher.h"
 
+#include "Account.hpp"
 #include "dialog-transfer.h"
 #include "dialog-utils.h"
 #include "gnc-glib-utils.h"
@@ -468,9 +469,8 @@ load_hash_tables (GNCImportMainMatcher *info)
     }
     for (GList *m = accounts_list; m; m = m->next)
     {
-        for (GList *n = xaccAccountGetSplitList (static_cast<Account*>(m->data)); n; n = n->next)
+        for (auto s : xaccAccountGetSplits (static_cast<Account*>(m->data)))
         {
-            auto s = static_cast<const Split*>(n->data);
             const Transaction *t = xaccSplitGetParent (s);
 
             const gchar *key = xaccTransGetDescription (t);
@@ -847,7 +847,7 @@ gnc_gen_trans_assign_transfer_account_to_selection_cb (GtkMenuItem *menuitem,
     bool is_selection = true;
     auto debugging_enabled{qof_log_check (G_LOG_DOMAIN, QOF_LOG_DEBUG)};
 
-    DEBUG("Rows in selection = %ld", selected_refs.size());
+    DEBUG("Rows in selection = %zu", selected_refs.size());
 
     for (const auto& ref : selected_refs)
     {
@@ -1138,7 +1138,17 @@ gnc_gen_trans_set_price_to_selection_cb (GtkMenuItem *menuitem,
         if (!gnc_xfer_dialog_run_until_done(xfer))
             break; /* If the user cancels, return to the payment dialog without changes */
 
-        gnc_import_TransInfo_set_price (row.get_trans_info (), exch);
+
+        /* Note the exchange rate we received is backwards from what we really need:
+         * it converts value to amount, but the remainder of the code expects
+         * an exchange rate that converts from amount to value. So let's invert
+         * the result (though only if that doesn't result in a division by 0). */
+        if (!gnc_numeric_zero_p(exch))
+        {
+            gnc_import_TransInfo_set_price (row.get_trans_info (),
+                                            gnc_numeric_invert(exch));
+            refresh_model_row (info, model, row.get_iter(), row.get_trans_info());
+        }
     }
     g_list_free_full (selected_rows, (GDestroyNotify)gtk_tree_path_free);
     LEAVE("");
@@ -1452,15 +1462,27 @@ gnc_gen_trans_onButtonPressed_cb (GtkTreeView *treeview,
         GdkEventButton *event_button = (GdkEventButton *) event;
         if (event_button->button == GDK_BUTTON_SECONDARY)
         {
-            DEBUG("Right mouseClick detected- popup the menu.");
-            // Only pop up the menu if there's more than 1 selected transaction,
-            // or the selected transaction is an ADD.
-            GtkTreeSelection *selection = gtk_tree_view_get_selection (treeview);
+            DEBUG("Right mouseClick detected - popup the menu.");
+
+            auto selection = gtk_tree_view_get_selection (treeview);
+            auto selected_rows = gtk_tree_selection_count_selected_rows (selection);
+            /* If no rows are selected yet, select the row that was clicked on
+             * before proceeding */
+            if (!selected_rows)
+            {
+                GtkTreePath* path = nullptr;
+                if (gtk_tree_view_get_path_at_pos (treeview, event_button->x,
+                    event_button->y, &path, nullptr, nullptr, nullptr))
+                {
+                    gtk_tree_selection_select_path (selection, path);
+                    selected_rows++;
+                    gtk_tree_path_free (path);
+                }
+            }
             if (gtk_tree_selection_count_selected_rows (selection) > 0)
             {
-                GList* selected;
                 GtkTreeModel *model;
-                selected = gtk_tree_selection_get_selected_rows (selection, &model);
+                auto selected = gtk_tree_selection_get_selected_rows (selection, &model);
                 if (get_action_for_path (static_cast<GtkTreePath*>(selected->data), model) == GNCImport_ADD)
                     gnc_gen_trans_view_popup_menu (treeview, event, info);
                 g_list_free_full (selected, (GDestroyNotify)gtk_tree_path_free);
