@@ -529,8 +529,8 @@ gnc_relative_date_to_time64(RelativeDatePeriod period)
         case RelativeDateOffset::QUARTER:
         {
             auto delta = (now.tm_mon > acct_per.tm_mon ?
-                          now.tm_mon - acct_per.tm_mon :
-                           acct_per.tm_mon - now.tm_mon) % 3;
+                          ( now.tm_mon - acct_per.tm_mon) % 3 :
+                          3 - ((acct_per.tm_mon - now.tm_mon) % 3));
             now.tm_mon = now.tm_mon - delta;
         }
             [[fallthrough]];
